@@ -15,7 +15,7 @@ copyright = '2019-2020, Collabora, Ltd. and the Ballparker contributors'
 author = 'Ryan Pavlik'
 
 version = '1.0'
-release = '1.0'
+release = '1.0.1'
 
 repo = 'https://gitlab.com/ryanpavlik/ballparker'
 main_branch = 'main'
